@@ -3,7 +3,7 @@
  * This file is meant to be included by applications using the relp library.
  * For relp library files themselves, include "relp.h".
  *
- * Copyright 2008-2018 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2025 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -189,7 +189,7 @@ typedef enum relpCmdEnaState_e relpCmdEnaState_t;
 #define CHKRet_Hdlr(code) if((iRet = code) != RELP_RET_OK)
 
 /* prototypes needed by library users */
-char *relpEngineGetVersion(void); /* use this entry point for configure check */
+const char *relpEngineGetVersion(void); /* use this entry point for configure check */
 void relpEngineSetShutdownImmdtPtr(relpEngine_t *pThis, int *ptr);
 relpRetVal relpEngineConstruct(relpEngine_t **ppThis);
 relpRetVal relpEngineDestruct(relpEngine_t **ppThis);
@@ -207,9 +207,11 @@ relpRetVal relpEngineRun(relpEngine_t *pThis);
 relpRetVal relpEngineCltDestruct(relpEngine_t *pThis, relpClt_t **ppClt);
 relpRetVal relpEngineCltConstruct(relpEngine_t *pThis, relpClt_t **ppClt);
 relpRetVal relpEngineSetSyslogRcv(relpEngine_t *pThis,
-				  relpRetVal (*pCB)(unsigned char*, unsigned char*, unsigned char*, size_t));
+                                  relpRetVal (*pCB)(unsigned char*, unsigned char*, unsigned char*, size_t));
 relpRetVal relpEngineSetSyslogRcv2(relpEngine_t *pThis,
-				  relpRetVal (*pCB)(void*, unsigned char*, unsigned char*, unsigned char*, size_t));
+                                  relpRetVal (*pCB)(void*, unsigned char*, unsigned char*, unsigned char*, size_t));
+relpRetVal relpEngineSetSyslogRcv3(relpEngine_t *pThis,
+                                  relpRetVal (*pCB)(void*, unsigned char*, unsigned char*, unsigned char*, unsigned char*, size_t));
 relpRetVal relpEngineSetEnableCmd(relpEngine_t *pThis, unsigned char *pszCmd, relpCmdEnaState_t stateCmd);
 relpRetVal relpEngineSetDnsLookupMode(relpEngine_t *pThis, int iMode);
 relpRetVal relpEngineSetOnAuthErr(relpEngine_t *pThis,
@@ -231,7 +233,6 @@ void relpSrvSetDHBits(relpSrv_t *pThis, int bits);
 void relpSrvSetKeepAlive(relpSrv_t *pThis, const int bEnabled, const int iKeepAliveIntvl,
 	const int iKeepAliveProbes, const int iKeepAliveTime);
 relpRetVal relpSrvSetGnuTLSPriString(relpSrv_t *pThis, char *pristr);
-relpRetVal relpSrvSetCACert(relpSrv_t *pThis, char *cert);
 relpRetVal relpSrvSetOwnCert(relpSrv_t *pThis, char *cert);
 relpRetVal relpSrvSetTlsConfigCmd(relpSrv_t *pThis, char *cfgcmd);
 relpRetVal relpSrvSetCACert(relpSrv_t *pThis, char *cert);
