@@ -1,6 +1,6 @@
 /* The RELP (reliable event logging protocol) core protocol library.
  *
- * Copyright 2008-2018 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2025 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -39,6 +39,8 @@
 	#define	NOTLS_UNUSED LIBRELP_ATTR_UNUSED
 #endif
 
+#define PART_OF_API __attribute__((visibility("default")))
+
 #include <pthread.h>
 #if HAVE_SYS_EPOLL_H
 #	include <sys/epoll.h>
@@ -123,14 +125,16 @@ typedef struct relpEngSessLst_s {
  */
 struct relpEngine_s {
 	BEGIN_RELP_OBJ;
-	void (*dbgprint)(char *fmt, ...) LIBRELP_ATTR_FORMAT(printf, 1, 2);
-	relpRetVal (*onSyslogRcv)(unsigned char*pHostname, unsigned char *pIP,
-		                  unsigned char *pMsg, size_t lenMsg); /**< callback for "syslog" cmd */
-	relpRetVal (*onSyslogRcv2)(void*, unsigned char*pHostname, unsigned char *pIP,
-		                  unsigned char *pMsg, size_t lenMsg); /**< callback for "syslog" cmd */
-	void (*onAuthErr)(void*pUsr, char *authinfo, char*errmsg, relpRetVal errcode);
-	void (*onErr)(void*pUsr, char *objinfo, char*errmsg, relpRetVal errcode);
-	void (*onGenericErr)(char *objinfo, char*errmsg, relpRetVal errcode);
+        void (*dbgprint)(char *fmt, ...) LIBRELP_ATTR_FORMAT(printf, 1, 2);
+        relpRetVal (*onSyslogRcv)(unsigned char*pHostname, unsigned char *pIP,
+                                  unsigned char *pMsg, size_t lenMsg); /**< callback for "syslog" cmd */
+        relpRetVal (*onSyslogRcv2)(void*, unsigned char*pHostname, unsigned char *pIP,
+                                  unsigned char *pMsg, size_t lenMsg); /**< callback for "syslog" cmd */
+       relpRetVal (*onSyslogRcv3)(void*, unsigned char*pHostname, unsigned char *pIP,
+                                  unsigned char *pPort, unsigned char *pMsg, size_t lenMsg); /**< callback for "syslog" cmd */
+        void (*onAuthErr)(void*pUsr, char *authinfo, char*errmsg, relpRetVal errcode);
+        void (*onErr)(void*pUsr, char *objinfo, char*errmsg, relpRetVal errcode);
+        void (*onGenericErr)(char *objinfo, char*errmsg, relpRetVal errcode);
 	int protocolVersion; /**< version of the relp protocol supported by this engine */
 
 	/* Flags */
@@ -230,7 +234,17 @@ static inline int relpEngineShouldStop(relpEngine_t *pThis) {
 /* prototypes needed by library itself (rest is in librelp.h) */
 relpRetVal relpEngineDispatchFrame(relpEngine_t *pThis, relpSess_t *pSess, relpFrame_t *pFrame);
 void LIBRELP_ATTR_FORMAT(printf, 4, 5) relpEngineCallOnGenericErr(relpEngine_t *pThis,
-	char *eobj, relpRetVal ecode, char *fmt, ...);
+	const char *eobj, relpRetVal ecode, const char *fmt, ...);
 const char * _relpEngine_strerror_r(const int errnum, char *buf, const size_t buflen);
 
+/* here we add some stuff from the compatibility layer. A separate include
+ * would be cleaner, but would potentially require changes all over the
+ * place. So doing it here is better. The respective replacement
+ * functions should usually be found under ./compat -- rgerhards, 2015-05-20
+ * - Function copied from rsyslog -- alorbach, 2020-11-13
+ */
+#ifndef HAVE_STRNDUP
+char * strndup(const char *s, size_t n);
+#endif
+
 #endif /* #ifndef RELP_H_INCLUDED */
