@@ -33,7 +33,7 @@
 #ifndef RELPCLT_H_INCLUDED
 #define	RELPCLT_H_INCLUDED
 
-/* the RELPCLT object 
+/* the RELPCLT object
  * rgerhards, 2008-03-16
  */
 struct relpClt_s {
@@ -49,12 +49,14 @@ struct relpClt_s {
 	char *caCertFile;
 	char *ownCertFile;
 	char *privKey;
+	char *tlsConfigCmd;	/**< optional configuration command property for TLS libs **/
 	relpPermittedPeers_t permittedPeers;
 	int protFamily;		/**< protocol family to connect over (IPv4, v6, ...) */
 	unsigned char *port;	/**< server port to connect to */
 	unsigned char *host;	/**< host(name) to connect to */
 	unsigned char *clientIP;/**< ip to bind to, or NULL if irrelevant */
 	unsigned timeout;	/**< session timeout */
+	int connTimeout;	/**< connection timeout */
 };
 
 
