@@ -40,6 +40,13 @@
 #include "relp.h"
 #include "cmdif.h"
 
+/* as a quick hack, we provide our command handler prototypes here
+ * right in front of the dispatcher. This saves us many otherwise-unneeded
+ * header files (and will go away if we make them dynamically loadable).
+ * alorbach, 2020-09-09
+ */
+/* core (protocol) commands */
+PROTOTYPEcommand(S, Rsp)
 
 /* read the response header. The frame's pData read pointer is moved to the
  * first byte of the response data buffer (if any).
@@ -97,7 +104,7 @@ BEGINcommand(S, Rsp)
 
 	ENTER_RELPFUNC;
 	CHKRet(readRspHdr(pFrame, &rspCode, bufText));
-	pSess->pEngine->dbgprint("in rsp command handler, txnr %d, code %d, text '%s'\n",
+	pSess->pEngine->dbgprint((char*)"in rsp command handler, txnr %d, code %d, text '%s'\n",
 				 pFrame->txnr, rspCode, bufText);
 	CHKRet(relpSessGetUnacked(pSess, &pSendbuf, pFrame->txnr));
 
@@ -108,8 +115,8 @@ BEGINcommand(S, Rsp)
 		CHKRet(relpSendbufDestruct(&pSendbuf));
 	} else {
 		if(pSess->pEngine->onErr != NULL) {
-			pSess->pEngine->onErr(pSess->pUsr, "rsp command",
-				"peer sent error response", RELP_RET_RSP_STATE_ERR);
+			pSess->pEngine->onErr(pSess->pUsr, (char*)"rsp command",
+				(char*)"peer sent error response", RELP_RET_RSP_STATE_ERR);
 		}
 		iRet = RELP_RET_RSP_STATE_ERR;
 		/* TODO: add a hock to a logger function of the caller */
