@@ -1,5 +1,6 @@
 #!/bin/bash
 . ${srcdir:=$(pwd)}/test-framework.sh
+check_command_available valgrind
 if [ "$VALGRIND" == "NO" ] ; then
    echo "valgrind tests are not permitted by environment config"
    exit 77
@@ -14,13 +15,13 @@ if [ $(uname) = "FreeBSD" ] ; then
 fi
 
 function actual_test() {
-	startup_receiver_valgrind --tls-lib $TEST_TLS_LIB -T -a "name" -e error.out.log --outfile $OUTFILE \
+	startup_receiver_valgrind -l $TEST_TLS_LIB -T -a "name" -e error.out.log -O $OUTFILE \
 		-x ${srcdir}/tls-certs/ca.pem -y ${srcdir}/tls-certs/cert.pem \
 		-z ${srcdir}/tls-certs/key.pem -P "rsyslog-client"
 
 	echo 'Send Message...'
 	libtool --mode=execute $valgrind \
-		./send --tls-lib $TEST_TLS_LIB -t 127.0.0.1 -p $TESTPORT -m "testmessage" -T \
+		./send -l $TEST_TLS_LIB -t 127.0.0.1 -p $TESTPORT -m "testmessage" -T \
 		-a "name" -x ${srcdir}/tls-certs/ca.pem -y ${srcdir}/tls-certs/cert.pem \
 		-z ${srcdir}/tls-certs/key.pem -P "rsyslog-client" $OPT_VERBOSE
 
