@@ -1,6 +1,7 @@
 #!/bin/bash
 . ${srcdir:=$(pwd)}/test-framework.sh
-startup_receiver -o truncate -m 144 -e $TESTDIR/error.out.log
+export errorlog="error.$LIBRELP_DYN.log"
+startup_receiver -o truncate -m 144 -e $TESTDIR/$errorlog
 
 echo 'Send Message...'
 ./send -t 127.0.0.1 -p $TESTPORT -m "testmessage" -d 154 1>>client.err.log 2>&1
@@ -8,6 +9,6 @@ echo 'Send Message...'
 stop_receiver
 # ^-sign symbolizes the beginning of the message and $-sign the expected end.
 check_output "^testmessage0123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012$"
-check_output "error.*frame too long" $TESTDIR/error.out.log
+check_output "error.*frame too long" $TESTDIR/$errorlog
 cat ${OUTFILE}
 terminate
